jaclearn.embedding.embedding\_utils
===================================

.. automodule:: jaclearn.embedding.embedding_utils

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      init_random
      make_element2idx
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: init_random

.. autofunction:: make_element2idx


